@@ -3,56 +3,57 @@ package IO::Socket::ByteCounter;
 use base 'IO::Socket';
 
 use strict;
-# use warnings;
+use warnings;
 
-use version;our $VERSION = qv('0.0.2');
+our $VERSION = 0.3;
 
 sub import {
     shift->record_bytes(@_) if @_;
 }
 
 sub record_bytes {
-	my ($self, @pkgs)     =  @_;
+    my ( $self, @pkgs ) = @_;
 
     for my $pkg (@pkgs) {
         $pkg = ref $pkg if ref $pkg;
-        
+
         my $inc = $pkg;
         $inc =~ s{::}{/}g;
-        if(!exists $INC{$inc . '.pm'}) {
+        if ( !exists $INC{ $inc . '.pm' } ) {
             eval "use $pkg;";
             warn $@ if $@;
             next if $@;
         }
-         
+
         no strict;
-        next if ${ "$pkg\::io_socket_bytecounter_on" };
-        
+        next if ${"$pkg\::io_socket_bytecounter_on"};
+
         eval <<"OVERRIDE_END";
             \$$pkg\::io_socket_bytecounter_on = 1;
-           
+            no warnings "redefine";
+
             #### IO::Socket methods ##
-            # IO::Socket::send   
+            # IO::Socket::send
             my \$send = \\&$pkg\::send;
             \*$pkg\::send = sub {
                 my \$self = \$_[0];
                 \${\*\$self}{'io_socket_bytecounter_out'} += IO::Socket::ByteCounter->_get_byte_size(\$_[1]);
-	            \$send->(\@_); 
+	            \$send->(\@_);
             };
-		 	
-            # IO::Socket::recv 
+
+            # IO::Socket::recv
             my \$recv = \\&$pkg\::recv;
             \*$pkg\::recv = sub {
                 my \$self = \$_[0];
 		        \${\*\$self}{'io_socket_bytecounter_in'} += \$_[2];
 		        \$recv->(\@_);
             };
-           
+
             #### IO::Handle methods ##
- 
- 
+
+
             #### new methods ##
-           
+
             sub $pkg\::get_bytes_in {
                 my \$self = \$_[0];
                 \${\*\$self}{'io_socket_bytecounter_in'};
@@ -62,7 +63,7 @@ sub record_bytes {
                 my \$self = \$_[0];
                 \${\*\$self}{'io_socket_bytecounter_out'};
             }
-            
+
             sub $pkg\::get_bytes_total {
                 my \$self = \$_[0];
                 \${\*\$self}{'io_socket_bytecounter_in'} + \${\*\$self}{'io_socket_bytecounter_out'};
@@ -75,16 +76,16 @@ OVERRIDE_END
 }
 
 sub _get_byte_size {
-    my($self, @strings) = @_;
+    my ( $self, @strings ) = @_;
     my $bytes = 0;
-    
+
     {
         use bytes;
         for my $string (@strings) {
             $bytes += length($string);
         }
     }
-    
+
     return $bytes;
 }
 
@@ -110,9 +111,9 @@ then:
 
     ... normal IO::Socket::INET object (as $sock) use ...
 
-    print 'Bytes out: ',   $sock->get_bytes_out,   "\n";  
+    print 'Bytes out: ',   $sock->get_bytes_out,   "\n";
     print 'Bytes in: ',    $sock->get_bytes_in ,   "\n";
-    print 'Bytes total: ', $sock->get_bytes_total, "\n";  
+    print 'Bytes total: ', $sock->get_bytes_total, "\n";
 
 =head1 METHODS
 
